==================
Advanced Radiomics
==================

.. image:: https://img.shields.io/travis/FelipeAugustoMachado/advanced-radiomics.svg
        :target: https://travis-ci.org/FelipeAugustoMachado/advanced-radiomics

.. image:: https://img.shields.io/pypi/v/advanced-radiomics.svg
        :target: https://pypi.python.org/pypi/advanced-radiomics


Advanced Radiomics Functions.

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://FelipeAugustoMachado.github.io/advanced-radiomics.

Features
--------

* TODO
